timeseries.SpaceCurve.snip — GDA Toolbox v1.0 Manual

# timeseries.SpaceCurve.snip

`SpaceCurve.` `snip`(time_step=60000000000, time_start=None, time_stop=None, overlap_ends=True)

  Cut this SpaceCurve into equal-time snippets. This is just a simple wrapper around self.slide( ) with time_step == window.

  time_step=60*10**9 == 1 minute

  Note! The trackids are unchanged! You might want to change them manually.

  Yields: | iterator of SpaceCurves To access the tracks as a list, do list( FT.snip() )

#### Previous topic

timeseries.SpaceCurve.slide

#### Next topic

Topological Constructions